package com.yfd.platform.modules.auxcontrol.service.impl;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjUtil;
import cn.hutool.core.util.StrUtil;
import com.yfd.platform.modules.auxcontrol.domain.DeviceWorkData;
import com.yfd.platform.modules.auxcontrol.mapper.DeviceSignalMapper;
import com.yfd.platform.modules.auxcontrol.mapper.DeviceWorkDataMapper;
import com.yfd.platform.modules.auxcontrol.service.IDeviceWorkDataService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 变电站-设备-运行数据 服务实现类
 * </p>
 *
 * @author zhengsl
 * @since 2025-04-23
 */
@Service
public class DeviceWorkDataServiceImpl extends ServiceImpl<DeviceWorkDataMapper, DeviceWorkData> implements IDeviceWorkDataService {
    @Resource
    private DeviceSignalMapper deviceSignalMapper;

    /**********************************
     * 用途说明: 导出变电站设备运行数据
     * 参数说明
     * deviceWorkDatas    所需导出的变电站设备运行数据项集合
     * 返回值说明: com.yfd.platform.config.ResponseResult 返回导出成功或者失败
     ***********************************/
    @Override
    public void insertData(String from, String slaveIp, String address, String value, String dateTimeString) {
        DeviceWorkData workdata = new DeviceWorkData();
        List<Map<String, Object>> list = new ArrayList<>();
        if ("IEC104".equals(from)) {
            list = deviceSignalMapper.selectDeviceSignal_Map(slaveIp, "yc", address);
        } else if ("IEC61850".equals(from)) {
            list = deviceSignalMapper.selectDeviceSignal_Map2("yc", address);
        }
        if (list.size() > 0) {
            Map<String, Object> map = list.get(0);
            workdata.setId(IdUtil.fastSimpleUUID());
            workdata.setSystemcode(map.get("systemcode").toString());
            workdata.setStationId(map.get("station_id").toString());
            workdata.setDeviceId(map.get("device_id").toString());
            workdata.setDeviceName(map.get("device_name").toString());
            workdata.setSignalId(map.get("signal_id").toString());
            workdata.setSignalName(map.get("signal_name").toString());
            workdata.setUnit(ObjUtil.isNotEmpty(map.get("signal_unit")) ? map.get("signal_unit").toString() : "");
            workdata.setValue(new BigDecimal(value));
            if (StrUtil.isEmpty(dateTimeString) || "null".equals(dateTimeString)) {
                workdata.setStartTime(LocalDateTime.now());
            } else {
                DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss.SSS");
                LocalDateTime localDateTime = LocalDateTime.parse(dateTimeString, formatter);
                workdata.setStartTime(localDateTime);
            }
            this.saveOrUpdate(workdata);

        }
    }

}
